import 'package:flutter/foundation.dart';
import 'package:http/http.dart' as http;

export 'native_phrase_api.dart' if (dart.library.html) 'web_phrase_api.dart';

const _kEuUrlDomain = 'ota.eu.phrase.com';
const _kUsUrlDomain = 'ota.us.phrase.com';

enum PhraseHost { eu, us }

class PhraseApiResult {
  PhraseApiResult._();
  factory PhraseApiResult.success(String version, String arb) =
      PhraseApiResultSuccess;
  factory PhraseApiResult.notModified() = PhraseApiResultNotModified;
}

class PhraseApiResultSuccess extends PhraseApiResult {
  PhraseApiResultSuccess(this.version, this.arb) : super._();
  final String version;
  final String arb;
}

class PhraseApiResultNotModified extends PhraseApiResult {
  PhraseApiResultNotModified() : super._();
}

abstract class PhraseApi {
  PhraseApi({
    http.Client? httpClient,
  }) : httpClient = httpClient ?? http.Client();

  final http.Client httpClient;

  String _getUrlDomainForHost(PhraseHost host) {
    switch (host) {
      case PhraseHost.eu:
        return _kEuUrlDomain;
      case PhraseHost.us:
        return _kUsUrlDomain;
    }
  }

  Future<PhraseApiResult> getTranslations(
    String distribution,
    String environment,
    PhraseHost host,
    String locale,
    String uuid,
    String? sdkVersion,
    String? lastUpdate,
    String? currentVersion,
    String? appVersion,
  ) async {
    Map<String, dynamic> params = <String, dynamic>{};
    params['client'] = 'flutter';
    params['sdk_version'] = sdkVersion;
    params['unique_identifier'] = uuid;
    if (lastUpdate != null) params['last_update'] = lastUpdate;
    if (currentVersion != null) params['current_version'] = currentVersion;
    if (appVersion != null) params['app_version'] = appVersion;

    var uri = Uri.https(
      _getUrlDomainForHost(host),
      '/$distribution/$environment/$locale/arb',
      params,
    );
    if (kDebugMode) debugPrint('OTA Request URL: $uri');

    return getPlatformTranslations(uri);
  }

  Future<PhraseApiResult> getPlatformTranslations(Uri uri);
}
