import 'dart:html' as html;

import '../phrase_exceptions.dart';
import 'base_phrase_api.dart';

class PlatformPhraseApi extends PhraseApi {
  @override
  Future<PhraseApiResult> getPlatformTranslations(Uri uri) async {
    final request = await html.HttpRequest.request(
      uri.toString(),
      method: 'GET',
    );

    final code = request.status;
    if (code == null) {
      throw PhraseApiException('failed to get updated translations');
    }

    switch (code) {
      case 304:
        return PhraseApiResult.notModified();
      case 200:
        return _processRequestResponse(request);
      default:
        throw PhraseApiException("Unexpected response code: $code");
    }
  }

  PhraseApiResult _processRequestResponse(html.HttpRequest request) {
    final currentUri = Uri.parse(request.responseUrl!);
    final version = currentUri.queryParameters['version'];
    if (version == null) throw PhraseApiException("Missing version");
    final arb = request.response;
    return PhraseApiResult.success(version, arb);
  }
}
