import 'dart:io';
import 'package:flutter/foundation.dart';
import 'package:path_provider/path_provider.dart';
import 'package:phrase/src/cache/phrase_cache.dart';
import 'package:synchronized/synchronized.dart';

class PhraseDiskCache implements PhraseCache {
  final Lock _lockDisk = Lock();

  @visibleForTesting
  Future<String> get cacheFolder async {
    final directory = await getApplicationDocumentsDirectory();
    return "${directory.path}/.phrase";
  }

  @override
  Future<void> write(String fn, String contents) =>
      _lockDisk.synchronized(() async {
        String folder = await cacheFolder;
        File file = File("$folder/$fn");
        await file
            .create(recursive: true)
            .then((f) => f.writeAsString(contents));
      });

  @override
  Future<String?> read(String fn) => _lockDisk.synchronized(() async {
        String folder = await cacheFolder;
        File file = File("$folder/$fn");
        if (await file.exists()) {
          return await file.readAsString();
        }
        return null;
      });
}
