import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:uuid/uuid.dart';

typedef GetSharedPreferencesCallback = Future<SharedPreferences> Function();
typedef GenerateUuidCallback = String Function({Map<String, dynamic>? options});

class PhrasePrefs {
  @visibleForTesting
  static const String kKeyUuid = "phrase_uuid";
  @visibleForTesting
  static const String kKeyLastUpdate = "phrase_last_update";

  PhrasePrefs({
    GetSharedPreferencesCallback? getSharedPreferencesCallback,
    Uuid? uuid,
  })  : _getSharedPreferences =
            getSharedPreferencesCallback ?? SharedPreferences.getInstance,
        _uuidGenerator = uuid ?? const Uuid();

  final GetSharedPreferencesCallback _getSharedPreferences;
  final Uuid _uuidGenerator;

  Future<String> getUUID() async {
    String? uuid = await _get(kKeyUuid);
    if (uuid != null) return uuid;
    uuid = _uuidGenerator.v4();
    await _put(kKeyUuid, uuid);
    return uuid;
  }

  Future<String?> getLastUpdate() => _get(kKeyLastUpdate);

  Future<void> setLastUpdate() => _put(kKeyLastUpdate,
      (DateTime.now().millisecondsSinceEpoch / 1000).round().toString());

  Future<String?> getVersion(String localeHash) =>
      _get(_keyTranslationVer(localeHash));

  Future<void> setVersion(String localeHash, String version) =>
      _put(_keyTranslationVer(localeHash), version);

  String _keyTranslationVer(String localeHash) => "phrase_version_$localeHash";

  Future<String?> _get(String key) async {
    SharedPreferences prefs = await _getSharedPreferences();
    return prefs.getString(key);
  }

  Future<void> _put(String key, String value) async {
    SharedPreferences prefs = await _getSharedPreferences();
    await prefs.setString(key, value);
  }
}
