import 'dart:io';

import 'package:flutter/services.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:phrase/src/cache/phrase_disk_cache.dart';

void main() {
  TestWidgetsFlutterBinding.ensureInitialized();

  setUpAll(() {
    const channel = MethodChannel(
      'plugins.flutter.io/path_provider',
    );
    TestDefaultBinaryMessengerBinding.instance.defaultBinaryMessenger
        .setMockMethodCallHandler(channel, (MethodCall methodCall) async {
      switch (methodCall.method) {
        case 'getApplicationDocumentsDirectory':
          return "test/_tmp";
        default:
      }
      return null;
    });
  });

  group('PhraseDiskCache', () {
    const filename = 'test_file.txt';
    late PhraseDiskCache cache;

    Future<void> removeTestFile() async {
      final folder = await cache.cacheFolder;
      final file = File('$folder/$filename');
      if (await file.exists()) {
        file.deleteSync();
      }
    }

    setUp(() async {
      cache = PhraseDiskCache();
      await removeTestFile();
    });

    tearDownAll(() {
      removeTestFile();
    });

    test('write and read', () async {
      const contents = 'test contents';
      await cache.write(filename, contents);
      final readContents = await cache.read(filename);
      expect(readContents, equals(contents));
    });

    test('read non-existent file', () async {
      final readContents = await cache.read('non_existent_file.txt');
      expect(readContents, isNull);
    });
  });
}
